#!/usr/bin/sh

#
# The source here is entirely from a jpeg-6b distribution execpt for:
#
# - jpeg-6b.sh (this file)
# - jpeg-6b-unixware.patch (patch file for UnixWare port)
#

set -x
set -e

# Apply patches.
for patch in jpeg-6b-unixware.patch
do
	[ -f .${patch}.applied ] || {
		/usr/bin/patch -c -p0 -i ${patch}
		/usr/bin/date > .${patch}.applied
	}
done

# Set build variables.
CFLAGS="-O -KPIC"
INSTALL="/usr/ucb/install"
export CFLAGS INSTALL

# Execute ./configure with options tailored for UnixWare.
./configure --prefix=/usr --exec_prefix=/usr

# Make libraries and install libraries and header files in cross environment.
${MAKE} DESTROOT=${TOOLS} install-lib

# Make everything and install in ${ROOT}/${MACH}.
${MAKE} DESTROOT=${ROOT}/${MACH} install install-lib

# Install README file as jpeg(7) man page.
${INSTALL} -d -m 0755 ${ROOT}/${MACH}/usr/man/cat.7
${INSTALL} -m 0444 README ${ROOT}/${MACH}/usr/man/cat.7/jpeg.7

# Install documentation files.
DOCDIR=/usr/share/doc/unixware/en/jpeg

${INSTALL} -d -m 0755 ${ROOT}/${MACH}/${DOCDIR}
${INSTALL} -m 0644 usage.doc ${ROOT}/${MACH}/${DOCDIR}/usage.txt
${INSTALL} -m 0644 wizard.doc ${ROOT}/${MACH}/${DOCDIR}/wizard.txt
${INSTALL} -m 0644 libjpeg.doc ${ROOT}/${MACH}/${DOCDIR}/libjpeg.txt
${INSTALL} -m 0644 example.c ${ROOT}/${MACH}/${DOCDIR}/example.c
${INSTALL} -m 0644 structure.doc ${ROOT}/${MACH}/${DOCDIR}/structure.txt

# Install documentation meta files.
SDK_home=${ROOT}/${MACH}/usr/share/meta/doc/UWDeveloper/SDKhome
SDK_group=${SDK_home}/SDKgroup
JPEG_home=${SDK_group}/JPEGhome
JPEG_group=${JPEG_home}/JPEGgroup

${INSTALL} -d -m 0755 ${SDK_home}
${INSTALL} -d -m 0755 ${SDK_group}
${INSTALL} -d -m 0755 ${JPEG_home}
${INSTALL} -d -m 0755 ${JPEG_group}

cat > ${SDK_home}/.directory <<EOF
[Desktop Entry]
Name=Software Development
Type=category
X-COL-IntroURI=/usr/share/doc/unixware/en/TopicViews/sdk_viewintro.html
EOF

cat > ${SDK_group}/.directory <<EOF
[Desktop Entry]
Name=Software Development
Type=group
EOF

cat > ${JPEG_home}/.directory <<EOF
[Desktop Entry]
Name=JPEG Documentation
Type=category
EOF

cat > ${JPEG_group}/.directory <<EOF
[Desktop Entry]
Name=JPEG Documentation
Type=group
EOF

cat > ${JPEG_group}/usage.desktop <<EOF
[Desktop Entry]
Name=Usage instructions for JPEG utilities
DocPath=${DOCDIR}/usage.txt
X-COL-rewrite=jpeg
X-COL-Weight=10
EOF

cat > ${JPEG_group}/wizard.desktop <<EOF
[Desktop Entry]
Name=Advanced usage instructions for JPEG wizards only
DocPath=${DOCDIR}/wizard.txt
X-COL-rewrite=jpeg
X-COL-Weight=20
EOF

cat > ${JPEG_group}/libjpeg.desktop <<EOF
[Desktop Entry]
Name=How to use the JPEG library in your own programs
DocPath=${DOCDIR}/libjpeg.txt
X-COL-rewrite=jpeg
X-COL-Weight=30
EOF

cat > ${JPEG_group}/example.desktop <<EOF
[Desktop Entry]
Name=Sample code for calling the JPEG library
DocPath=${DOCDIR}/example.c
X-COL-rewrite=jpeg
X-COL-Weight=40
EOF

cat > ${JPEG_group}/structure.desktop <<EOF
[Desktop Entry]
Name=Overview of the JPEG library's internal structure
DocPath=${DOCDIR}/strcuture.txt
X-COL-rewrite=jpeg
X-COL-Weight=50
EOF
